@@ -55,7 +55,7 @@ struct corpus_filter_prop {
  */
 struct corpus_filter {
 	struct corpus_symtab symtab;	/**< symbol table */
-	struct corpus_render render;	/**< type renderer */
+	struct utf8lite_render render;	/**< type renderer */
 	struct corpus_tree combine;	/**< word sequences to combine */
 	int *combine_rules;		/**< properties for nodes in the
 					  combine tree */
@@ -64,9 +64,9 @@ struct corpus_filter {
 	struct corpus_filter_prop *props;/**< type properties */
 	struct corpus_wordscan scan;	/**< current word scan */
 	int flags;			/**< filter flags */
-	uint32_t connector;		/**< word connector */
+	int32_t connector;		/**< word connector */
 	int has_scan;			/**< whether a scan is in progress */
-	struct corpus_text current;	/**< current token */
+	struct utf8lite_text current;	/**< current token */
 	int type_id;			/**< current type ID */
 	int error;			/**< last error code */
 };
@@ -86,7 +86,7 @@ struct corpus_filter {
  * \returns 0 on success
  */
 int corpus_filter_init(struct corpus_filter *f, int flags, int type_kind,
-		       uint32_t connector, corpus_stem_func stemmer,
+		       int32_t connector, corpus_stem_func stemmer,
 		       void *context);
 
 /**
@@ -105,7 +105,7 @@ void corpus_filter_destroy(struct corpus_filter *f);
  * \returns 0 on success
  */
 int corpus_filter_stem_except(struct corpus_filter *f,
-			      const struct corpus_text *symbol);
+			      const struct utf8lite_text *symbol);
 
 /**
  * Add a combination rule to to filter.
@@ -116,7 +116,7 @@ int corpus_filter_stem_except(struct corpus_filter *f,
  * \returns 0 on success
  */
 int corpus_filter_combine(struct corpus_filter *f,
-			  const struct corpus_text *tokens);
+			  const struct utf8lite_text *tokens);
 
 /**
  * Add a type to a filter table if it does not already exist there, and
@@ -129,7 +129,7 @@ int corpus_filter_combine(struct corpus_filter *f,
  * \returns 0 on success
  */
 int corpus_filter_add_type(struct corpus_filter *f,
-			   const struct corpus_text *typ, int *idptr);
+			   const struct utf8lite_text *typ, int *idptr);
 
 /**
  * Add a type to the filter's drop list.
@@ -140,7 +140,7 @@ int corpus_filter_add_type(struct corpus_filter *f,
  * \returns 0 on success
  */
 int corpus_filter_drop(struct corpus_filter *f,
-		       const struct corpus_text *type);
+		       const struct utf8lite_text *type);
 
 /**
  * Add a type to the filter's drop exception list. This overrides the
@@ -153,7 +153,7 @@ int corpus_filter_drop(struct corpus_filter *f,
  * \returns 0 on success
  */
 int corpus_filter_drop_except(struct corpus_filter *f,
-			      const struct corpus_text *type);
+			      const struct utf8lite_text *type);
 
 /**
  * Start scanning a text.
@@ -164,7 +164,7 @@ int corpus_filter_drop_except(struct corpus_filter *f,
  * \returns 0 on success
  */
 int corpus_filter_start(struct corpus_filter *f,
-			const struct corpus_text *text);
+			const struct utf8lite_text *text);
 
 /**
  * Advance a text to the next type.
